@@ -1,5 +1,5 @@
 package App::Countdown;
-$App::Countdown::VERSION = '0.8.1';
+$App::Countdown::VERSION = '0.8.2';
 use 5.010;
 
 use strict;
@@ -218,9 +218,13 @@ __END__
 
 =encoding UTF-8
 
+=head1 NAME
+
+App::Countdown - wait some specified time while displaying the remaining time.
+
 =head1 VERSION
 
-version 0.8.1
+version 0.8.2
 
 =head1 SYNOPSIS
 
@@ -228,10 +232,6 @@ version 0.8.1
 
     App::Countdown->new({ argv => [@ARGV] })->run();
 
-=head1 NAME
-
-App::Countdown - wait some specified time while displaying the remaining time.
-
 =head1 SUBROUTINES/METHODS
 
 =head2 new
@@ -317,7 +317,7 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -354,14 +354,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-Countdown>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/App-Countdown>
-
-=item *
-
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
@@ -433,7 +425,7 @@ feature.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2019 by Shlomi Fish.
+This software is Copyright (c) 2020 by Shlomi Fish.
 
 This is free software, licensed under:
 
